<!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
<qgis version="3.22.5-Bia?owie?a">
  <identifier>GagaesII_subset</identifier>
  <parentidentifier></parentidentifier>
  <language>ENG</language>
  <type>dataset</type>
  <title>GagaesII_subset</title>
  <abstract></abstract>
  <contact>
    <name></name>
    <organization></organization>
    <position></position>
    <voice></voice>
    <fax></fax>
    <email></email>
    <role></role>
  </contact>
  <links/>
  <fees></fees>
  <encoding></encoding>
  <crs>
    <spatialrefsys>
      <wkt></wkt>
      <proj4></proj4>
      <srsid>0</srsid>
      <srid>0</srid>
      <authid></authid>
      <description></description>
      <projectionacronym></projectionacronym>
      <ellipsoidacronym></ellipsoidacronym>
      <geographicflag>false</geographicflag>
    </spatialrefsys>
  </crs>
  <extent>
    <spatial crs="" miny="0" maxx="0" minz="0" dimensions="2" maxz="0" minx="0" maxy="0"/>
    <temporal>
      <period>
        <start></start>
        <end></end>
      </period>
    </temporal>
  </extent>
</qgis>
